
# Slot: mixins


List of definitions to be mixed in. Targets may be any definition of the same type

URI: [linkml:mixins](https://w3id.org/linkml/mixins)


## Domain and Range

[Definition](Definition.md) &#8594;  <sub>0..\*</sub> [Definition](Definition.md)

## Parents


## Children

 *  [class_definition➞mixins](class_definition_mixins.md)
 *  [permissible_value➞mixins](permissible_value_mixins.md)
 *  [slot_definition➞mixins](slot_definition_mixins.md)

## Used by

 * [Definition](Definition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | traits |
| **Comments:** | | mixins act in the same way as parents (is_a). They allow a model to have a primary strict hierachy, while keeping the benefits of multiple inheritance |
| **See also:** | | [https://en.wikipedia.org/wiki/Mixin](https://en.wikipedia.org/wiki/Mixin) |

